#!/usr/bin/env python3

from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization

from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.asymmetric import padding

from cryptography.exceptions import InvalidSignature


def verify(data_file_name, signature_file_name, public_key_file_name):
    # read data
    data_file = open(data_file_name, 'rb')
    data = data_file.read()
    data_file.close()

    # read signature
    signature_file = open(signature_file_name, 'rb')
    signature = signature_file.read()
    signature_file.close()

    # read public key file
    key_file = open(public_key_file_name, 'rb')
    key_data = key_file.read()
    key_file.close()

    public_key = serialization.load_pem_public_key(
        key_data,
        backend=default_backend()
    )

    verify_ok = False

    try:
        public_key.verify(
            signature,
            data,
            padding.PKCS1v15(),
            hashes.SHA256()
        )
    except InvalidSignature:
        print('invalid signature!')
    else:
        verify_ok = True

    return verify_ok


if __name__ == '__main__':
    data_file = r'data.bin'
    signature_file = r'signature.bin'
    public_key_file = r'Key_pub.pem'

    verify_ok = verify(data_file, signature_file, public_key_file)
    if verify_ok:
        print('verify ok!')
    else:
        print('verify fail!')